pytilities.event.test.testall

Package pytilities :: Package event :: Package test :: Module testall |
[hide private]
[frames] | no frames]

# Module testall

source code

Functions | [hide private]
run() | source code

Variables | [hide private]
| test_suite = `<unittest.TestSuite tests=[<unittest.TestSuite te`...``
| __package__ = ``'``pytilities.event.test``'``

Variables Details | [hide private]

  ### test_suite Value:
      <unittest.TestSuite tests=[<unittest.TestSuite tests=[<unittest.TestSu
      ite tests=[]>, <unittest.TestSuite tests=[<unittest.TestSuite tests=[<
      pytilities.event.test.decorators.BDispatcherTestCase testMethod=test_s
      uccess>]>, <unittest.TestSuite tests=[]>, <unittest.TestSuite tests=[<
      pytilities.event.test.decorators.DispatcherTestCase testMethod=test_su
      ccess>]>, <unittest.TestSuite tests=[<pytilities.event.test.decorators
      .SwitchTestCase testMethod=test_success>]>]>, <unittest.TestSuite test
      s=[<unittest.TestSuite tests=[<pytilities.event.test.dispatcher.InitTe
      ...